Here is my diff for the renaming of the getline function in base.
Please, test it and tell me everything that is wrong with it.
 
-- 
Jan

Index: bin/pax/options.c
===================================================================
RCS file: /cvs/src/bin/pax/options.c,v
retrieving revision 1.74
diff -u -p -U0 -r1.74 options.c
--- bin/pax/options.c   2 Dec 2010 04:08:27 -0000       1.74
+++ bin/pax/options.c   19 Feb 2012 11:24:57 -0000
@@ -67 +67 @@ static off_t str_offt(char *);
-static char *getline(FILE *fp);
+static char *get_line(FILE *fp);
@@ -887 +887 @@ tar_options(int argc, char **argv)
-                                       while ((str = getline(fp)) != NULL) {
+                                       while ((str = get_line(fp)) != NULL) {
@@ -966 +966 @@ tar_options(int argc, char **argv)
-                               while ((str = getline(fp)) != NULL) {
+                               while ((str = get_line(fp)) != NULL) {
@@ -1188 +1188 @@ cpio_options(int argc, char **argv)
-                               while ((str = getline(fp)) != NULL) {
+                               while ((str = get_line(fp)) != NULL) {
@@ -1287 +1287 @@ cpio_options(int argc, char **argv)
-                       while ((str = getline(stdin)) != NULL) {
+                       while ((str = get_line(stdin)) != NULL) {
@@ -1518 +1518 @@ char *
-getline(FILE *f)
+get_line(FILE *f)
Index: games/boggle/boggle/bog.c
===================================================================
RCS file: /cvs/src/games/boggle/boggle/bog.c,v
retrieving revision 1.20
diff -u -p -U0 -r1.20 bog.c
--- games/boggle/boggle/bog.c   27 Oct 2009 23:59:24 -0000      1.20
+++ games/boggle/boggle/bog.c   19 Feb 2012 11:24:58 -0000
@@ -277 +277 @@ playgame(void)
-               if (getline(buf) == NULL) {
+               if (get_line(buf) == NULL) {
Index: games/boggle/boggle/extern.h
===================================================================
RCS file: /cvs/src/games/boggle/boggle/extern.h,v
retrieving revision 1.6
diff -u -p -U0 -r1.6 extern.h
--- games/boggle/boggle/extern.h        3 Jun 2003 03:01:39 -0000       1.6
+++ games/boggle/boggle/extern.h        19 Feb 2012 11:24:58 -0000
@@ -45 +45 @@ void       flushin(FILE *);
-char   *getline(char *);
+char   *get_line(char *);
Index: games/boggle/boggle/mach.c
===================================================================
RCS file: /cvs/src/games/boggle/boggle/mach.c,v
retrieving revision 1.12
diff -u -p -U0 -r1.12 mach.c
--- games/boggle/boggle/mach.c  27 Oct 2009 23:59:24 -0000      1.12
+++ games/boggle/boggle/mach.c  19 Feb 2012 11:24:59 -0000
@@ -197 +197 @@ char *
-getline(char *q)
+get_line(char *q)
Index: games/cribbage/crib.c
===================================================================
RCS file: /cvs/src/games/cribbage/crib.c,v
retrieving revision 1.15
diff -u -p -U0 -r1.15 crib.c
--- games/cribbage/crib.c       10 May 2010 08:53:12 -0000      1.15
+++ games/cribbage/crib.c       19 Feb 2012 11:24:59 -0000
@@ -210 +210 @@ game(void)
-                                       foo = getline();
+                                       foo = get_line();
@@ -392 +392 @@ cut(bool mycrib, int pos)
-                               foo = getline();
+                               foo = get_line();
Index: games/cribbage/cribbage.h
===================================================================
RCS file: /cvs/src/games/cribbage/cribbage.h,v
retrieving revision 1.9
diff -u -p -U0 -r1.9 cribbage.h
--- games/cribbage/cribbage.h   10 May 2010 08:53:12 -0000      1.9
+++ games/cribbage/cribbage.h   19 Feb 2012 11:24:59 -0000
@@ -81 +81 @@ void       gamescore(void);
-char   *getline(void);
+char   *get_line(void);
Index: games/cribbage/io.c
===================================================================
RCS file: /cvs/src/games/cribbage/io.c,v
retrieving revision 1.13
diff -u -p -U0 -r1.13 io.c
--- games/cribbage/io.c 10 May 2010 08:53:12 -0000      1.13
+++ games/cribbage/io.c 19 Feb 2012 11:24:59 -0000
@@ -219 +219 @@ incard(CARD *crd)
-       if (!(line = getline()))
+       if (!(line = get_line()))
@@ -318 +318 @@ number(int lo, int hi, char *prompt)
-               if (!(p = getline()) || *p == '\0') {
+               if (!(p = get_line()) || *p == '\0') {
@@ -508 +508 @@ over:
- * getline:
+ * get_line:
@@ -513 +513 @@ char *
-getline(void)
+get_line(void)
Index: games/gomoku/bdisp.c
===================================================================
RCS file: /cvs/src/games/gomoku/bdisp.c,v
retrieving revision 1.10
diff -u -p -U0 -r1.10 bdisp.c
--- games/gomoku/bdisp.c        27 Oct 2009 23:59:24 -0000      1.10
+++ games/gomoku/bdisp.c        19 Feb 2012 11:24:59 -0000
@@ -251 +251 @@ int
-getline(buf, size)
+get_line(buf, size)
Index: games/gomoku/gomoku.h
===================================================================
RCS file: /cvs/src/games/gomoku/gomoku.h,v
retrieving revision 1.9
diff -u -p -U0 -r1.9 gomoku.h
--- games/gomoku/gomoku.h       16 Jan 2004 00:13:19 -0000      1.9
+++ games/gomoku/gomoku.h       19 Feb 2012 11:24:59 -0000
@@ -288 +288 @@ int     getcoord(void);
-int    getline(char *, int);
+int    get_line(char *, int);
Index: games/gomoku/main.c
===================================================================
RCS file: /cvs/src/games/gomoku/main.c,v
retrieving revision 1.22
diff -u -p -U0 -r1.22 main.c
--- games/gomoku/main.c 27 Oct 2009 23:59:24 -0000      1.22
+++ games/gomoku/main.c 19 Feb 2012 11:25:00 -0000
@@ -165 +165 @@ again:
-               getline(buf, sizeof(buf));
+               get_line(buf, sizeof(buf));
@@ -242 +242 @@ again:
-                                       (void)getline(fname, sizeof(fname));
+                                       (void)get_line(fname, sizeof(fname));
@@ -260 +260 @@ again:
-                               if (!getline(buf, sizeof(buf))) {
+                               if (!get_line(buf, sizeof(buf))) {
@@ -310 +310 @@ again:
-                       if (getline(buf, sizeof(buf)) &&
+                       if (get_line(buf, sizeof(buf)) &&
@@ -317 +317 @@ again:
-                               (void)getline(buf, sizeof(buf));
+                               (void)get_line(buf, sizeof(buf));
@@ -367 +367 @@ top:
-       if (!getline(fmtbuf, sizeof(fmtbuf)))
+       if (!get_line(fmtbuf, sizeof(fmtbuf)))
Index: gnu/usr.bin/cvs/lib/getline.c
===================================================================
RCS file: /cvs/src/gnu/usr.bin/cvs/lib/getline.c,v
retrieving revision 1.1.1.5
diff -u -p -U0 -r1.1.1.5 getline.c
--- gnu/usr.bin/cvs/lib/getline.c       10 Feb 2001 18:57:24 -0000      1.1.1.5
+++ gnu/usr.bin/cvs/lib/getline.c       19 Feb 2012 11:25:15 -0000
@@ -157 +157 @@ int
-getline (lineptr, n, stream)
+get_line (lineptr, n, stream)
Index: gnu/usr.bin/cvs/lib/getline.h
===================================================================
RCS file: /cvs/src/gnu/usr.bin/cvs/lib/getline.h,v
retrieving revision 1.1.1.3
diff -u -p -U0 -r1.1.1.3 getline.h
--- gnu/usr.bin/cvs/lib/getline.h       10 Feb 2001 18:57:26 -0000      1.1.1.3
+++ gnu/usr.bin/cvs/lib/getline.h       19 Feb 2012 11:25:15 -0000
@@ -15 +15 @@ int
-  getline __PROTO ((char **_lineptr, size_t *_n, FILE *_stream));
+  get_line __PROTO ((char **_lineptr, size_t *_n, FILE *_stream));
Index: include/stdio.h
===================================================================
RCS file: /cvs/src/include/stdio.h,v
retrieving revision 1.41
diff -u -p -U0 -r1.41 stdio.h
--- include/stdio.h     18 Jul 2011 17:29:49 -0000      1.41
+++ include/stdio.h     19 Feb 2012 11:25:31 -0000
@@ -325,0 +326,5 @@ int  putchar_unlocked(int);
+#if __POSIX_VISIBLE >= 200809
+ssize_t         getdelim(char** lineptr, size_t* n, int delim, FILE* fp);
+ssize_t         getline(char** lineptr, size_t* n, FILE* fp);
+#endif
+
Index: lib/libc/stdio/Makefile.inc
===================================================================
RCS file: /cvs/src/lib/libc/stdio/Makefile.inc,v
retrieving revision 1.21
diff -u -p -U0 -r1.21 Makefile.inc
--- lib/libc/stdio/Makefile.inc 18 Jan 2012 14:01:38 -0000      1.21
+++ lib/libc/stdio/Makefile.inc 19 Feb 2012 11:25:32 -0000
@@ -21 +21,2 @@ SRCS+=  asprintf.c clrerr.c fclose.c fdop
-       fwscanf.c swscanf.c vfwscanf.c vswscanf.c vwscanf.c wscanf.c
+       fwscanf.c swscanf.c vfwscanf.c vswscanf.c vwscanf.c wscanf.c \
+       getdelim.c
@@ -26 +27,2 @@ MAN+=   fclose.3 ferror.3 fflush.3 fgetln.
-       fgetws.3 fputws.3 fwide.3 getwc.3 putwc.3 ungetwc.3 wprintf.3 wscanf.3
+       fgetws.3 fputws.3 fwide.3 getwc.3 putwc.3 ungetwc.3 wprintf.3 wscanf.3 \
+       getdelim.3
Index: lib/libc/stdio/getdelim.3
===================================================================
RCS file: lib/libc/stdio/getdelim.3
diff -N lib/libc/stdio/getdelim.3
--- /dev/null   1 Jan 1970 00:00:00 -0000
+++ lib/libc/stdio/getdelim.3   19 Feb 2012 11:25:32 -0000
@@ -0,0 +1,156 @@
+.\"     $OpenBSD$
+.\"     $NetBSD: getdelim.3,v 1.9 2011/04/20 23:37:51 enami Exp $
+.\"
+.\" Copyright (c) 2009 The NetBSD Foundation, Inc.
+.\" All rights reserved.
+.\"
+.\" This code is derived from software contributed to The NetBSD Foundation
+.\" by Roy Marples.
+.\"
+.\" Redistribution and use in source and binary forms, with or without
+.\" modification, are permitted provided that the following conditions
+.\" are met:
+.\" 1. Redistributions of source code must retain the above copyright
+.\"    notice, this list of conditions and the following disclaimer.
+.\" 2. Redistributions in binary form must reproduce the above copyright
+.\"    notice, this list of conditions and the following disclaimer in the
+.\"    documentation and/or other materials provided with the distribution.
+.\"
+.\" THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
+.\" ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
+.\" TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+.\" PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
+.\" BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+.\" CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+.\" SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+.\" INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+.\" CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+.\" ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+.\" POSSIBILITY OF SUCH DAMAGE.
+.\"
+.Dd $Mdocdate$
+.Dt GETDELIM 3
+.Os
+.Sh NAME
+.Nm getdelim ,
+.Nm getline
+.Nd read a delimited record from a stream
+.Sh LIBRARY
+.Lb libc
+.Sh SYNOPSIS
+.In stdio.h
+.Ft ssize_t
+.Fn getdelim "char ** restrict lineptr" "size_t * restrict n" "int delimiter" 
"FILE * restrict stream"
+.Ft ssize_t
+.Fn getline "char ** restrict lineptr" "size_t * restrict n" "FILE * restrict 
stream"
+.Sh DESCRIPTION
+The
+.Fn getdelim
+function reads from the
+.Fa stream
+until it encounters a character matching
+.Fa delimiter ,
+storing the input in
+.Fa *lineptr .
+The buffer is
+.Dv NUL Ns No -terminated
+and includes the delimiter.
+The
+.Fa delimiter
+character must be representable as an unsigned char.
+.Pp
+If
+.Fa *n
+is non-zero, then
+.Fa *lineptr
+must be pre-allocated to at least
+.Fa *n
+bytes.
+The buffer should be allocated dynamically;
+it must be possible to
+.Xr free 3
+.Fa *lineptr .
+.Fn getdelim
+ensures that
+.Fa *lineptr
+is large enough to hold the input, updating
+.Fa *n
+to reflect the new size.
+.Pp
+The
+.Fn getline
+function is equivalent to
+.Fn getdelim
+with
+.Fa delimiter
+set to the newline character.
+.Sh RETURN VALUES
+The
+.Fn getdelim
+and
+.Fn getline
+functions return the number of characters read, including the delimiter.
+If no characters were read and the stream is at end-of-file, the functions
+return \-1.
+If an error occurs, the functions return \-1 and the global variable
+.Va errno
+is set to indicate the error.
+.Pp
+The functions do not distinguish between end-of-file and error,
+and callers must use
+.Xr feof 3
+and
+.Xr ferror 3
+to determine which occurred.
+.Sh EXAMPLES
+The following code fragment reads lines from a file and writes them to
+standard output.
+.Bd -literal -offset indent
+char *line = NULL;
+size_t linesize = 0;
+ssize_t linelen;
+
+while ((linelen = getline(\*[Am]line, \*[Am]linesize, fp)) != -1)
+       fwrite(line, linelen, 1, stdout);
+
+if (ferror(fp))
+       perror("getline");
+.Ed
+.Sh ERRORS
+.Bl -tag -width [EOVERFLOW]
+.It Bq Er EINVAL
+.Fa lineptr
+or
+.Fa n
+is a
+.Dv NULL
+pointer.
+.It Bq Er EOVERFLOW
+More than SSIZE_MAX characters were read without encountering the delimiter.
+.El
+.Pp
+The
+.Fn getdelim
+and
+.Fn getline
+functions may also fail and set
+.Va errno
+for any of the errors specified in the routines
+.Xr fflush 3 ,
+.Xr malloc 3 ,
+.Xr read 2 ,
+.Xr stat 2 ,
+or
+.Xr realloc 3 .
+.Sh SEE ALSO
+.Xr ferror 3 ,
+.Xr fgets 3 ,
+.Xr fgetln 3 ,
+.Xr fopen 3
+.Sh STANDARDS
+The
+.Fn getdelim
+and
+.Fn getline
+functions conform to
+.St -p1003.1-2008 .
Index: lib/libc/stdio/getdelim.c
===================================================================
RCS file: lib/libc/stdio/getdelim.c
diff -N lib/libc/stdio/getdelim.c
--- /dev/null   1 Jan 1970 00:00:00 -0000
+++ lib/libc/stdio/getdelim.c   19 Feb 2012 11:25:32 -0000
@@ -0,0 +1,104 @@
+/* $OpenBSD$ */
+
+/*
+ * Copyright (c) 2012 Jan Klemkow <[email protected]>
+ *
+ * Permission to use, copy, modify, and distribute this software for any
+ * purpose with or without fee is hereby granted, provided that the above
+ * copyright notice and this permission notice appear in all copies.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
+ * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
+ * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
+ * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+ * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
+ * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
+ * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ */
+
+#include <errno.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <limits.h>
+#include "local.h"
+
+ssize_t
+getdelim(char** lineptr, size_t* n, int delim, FILE* fp)
+{
+       char* c;
+       char* newp;
+       size_t len = 0;
+       size_t offset = 0;
+
+       if (lineptr == NULL || n == NULL || fp == NULL) {
+               errno = EINVAL;
+               return -1;
+       }
+
+       FLOCKFILE(fp);
+       do {
+               /* if file buffer is empty, refill it */
+               if (fp->_r <= 0)
+                       __srefill(fp);
+
+               /* search for delimiter in fp buffer */
+               if ((c = memchr((void*)fp->_p, delim, (size_t)fp->_r)) == NULL){
+                       /* delimiter not found */
+                       len = (size_t) fp->_r;
+               } else {
+                       /* found delimiter */
+                       len = (size_t) (c - (char*) fp->_p);
+                       len++;
+               }
+
+               /* checking for enought space in buffer lineptr */
+               if (*n < offset + len + 1) {
+                       if (offset + len > SSIZE_MAX) {
+                               FUNLOCKFILE(fp);
+                               errno = EOVERFLOW;
+                               return -1;
+                       }
+
+                       /* duplicate the buffersize of line */
+                       *n <<= 1;
+
+                       /*
+                        * Starting with BUFSIZ if the application starts with
+                        * an empty buffer.
+                        */
+                       if (*n == 0)
+                               *n = BUFSIZ;
+
+                       if ((newp = realloc(*lineptr, *n)) == NULL) {
+                               FUNLOCKFILE(fp);
+                               free(*lineptr);
+                               *lineptr = NULL;
+                               *n = 0;
+                               errno = ENOMEM;
+                               return -1;
+                       }
+                       *lineptr = newp;
+               }
+       
+               memcpy((void*) (*lineptr + offset), (void*)fp->_p, len);
+               offset += len;
+               fp->_r -= len;
+               fp->_p += len;
+       } while (c == NULL && len != 0);
+       FUNLOCKFILE(fp);
+
+       *(*lineptr + offset) = '\0';
+
+       /* end of file */
+       if (offset == 0)
+               return -1;
+
+       return (ssize_t) offset;
+}
+
+ssize_t
+getline(char** lineptr, size_t* n, FILE* fp)
+{
+       return getdelim(lineptr, n, '\n', fp);
+}
Index: libexec/ftpd/extern.h
===================================================================
RCS file: /cvs/src/libexec/ftpd/extern.h,v
retrieving revision 1.17
diff -u -p -U0 -r1.17 extern.h
--- libexec/ftpd/extern.h       12 Sep 2008 16:12:08 -0000      1.17
+++ libexec/ftpd/extern.h       19 Feb 2012 11:25:38 -0000
@@ -72 +72 @@ FILE   *ftpd_popen(char *, char *);
-int     getline(char *, int, FILE *);
+int     get_line(char *, int, FILE *);
Index: libexec/ftpd/ftpcmd.y
===================================================================
RCS file: /cvs/src/libexec/ftpd/ftpcmd.y,v
retrieving revision 1.53
diff -u -p -U0 -r1.53 ftpcmd.y
--- libexec/ftpd/ftpcmd.y       27 Oct 2009 23:59:31 -0000      1.53
+++ libexec/ftpd/ftpcmd.y       19 Feb 2012 11:25:38 -0000
@@ -1080 +1080 @@ lookup(p, cmd)
- * getline - a hacked up version of fgets to ignore TELNET escape codes.
+ * get_line - a hacked up version of fgets to ignore TELNET escape codes.
@@ -1083 +1083 @@ int
-getline(s, n, iop)
+get_line(s, n, iop)
@@ -1198 +1198 @@ yylex()
-                       n = getline(cbuf, sizeof(cbuf)-1, stdin);
+                       n = get_line(cbuf, sizeof(cbuf)-1, stdin);
Index: usr.bin/ctags/C.c
===================================================================
RCS file: /cvs/src/usr.bin/ctags/C.c,v
retrieving revision 1.13
diff -u -p -U0 -r1.13 C.c
--- usr.bin/ctags/C.c   3 Nov 2010 19:39:38 -0000       1.13
+++ usr.bin/ctags/C.c   19 Feb 2012 11:25:53 -0000
@@ -158 +158 @@ endtok:                 if (sp > tok) {
-                               getline();
+                               get_line();
@@ -187 +187 @@ endtok:                 if (sp > tok) {
-                               getline();
+                               get_line();
@@ -236 +236 @@ endtok:                 if (sp > tok) {
-                                       getline();
+                                       get_line();
@@ -416 +416 @@ hash_entry(void)
-               getline();
+               get_line();
Index: usr.bin/ctags/ctags.h
===================================================================
RCS file: /cvs/src/usr.bin/ctags/ctags.h,v
retrieving revision 1.6
diff -u -p -U0 -r1.6 ctags.h
--- usr.bin/ctags/ctags.h       3 Nov 2010 19:39:38 -0000       1.6
+++ usr.bin/ctags/ctags.h       19 Feb 2012 11:25:53 -0000
@@ -79 +79 @@ extern int        cicmp(char *);
-extern void    getline(void);
+extern void    get_line(void);
Index: usr.bin/ctags/fortran.c
===================================================================
RCS file: /cvs/src/usr.bin/ctags/fortran.c,v
retrieving revision 1.7
diff -u -p -U0 -r1.7 fortran.c
--- usr.bin/ctags/fortran.c     27 Oct 2009 23:59:37 -0000      1.7
+++ usr.bin/ctags/fortran.c     19 Feb 2012 11:25:53 -0000
@@ -121 +121 @@ PF_funcs(void)
-               getline();                      /* process line for ex(1) */
+               get_line();                     /* process line for ex(1) */
Index: usr.bin/ctags/lisp.c
===================================================================
RCS file: /cvs/src/usr.bin/ctags/lisp.c,v
retrieving revision 1.6
diff -u -p -U0 -r1.6 lisp.c
--- usr.bin/ctags/lisp.c        27 Oct 2009 23:59:37 -0000      1.6
+++ usr.bin/ctags/lisp.c        19 Feb 2012 11:25:53 -0000
@@ -96 +96 @@ l_entries(void)
-               getline();
+               get_line();
Index: usr.bin/ctags/print.c
===================================================================
RCS file: /cvs/src/usr.bin/ctags/print.c,v
retrieving revision 1.6
diff -u -p -U0 -r1.6 print.c
--- usr.bin/ctags/print.c       27 Oct 2009 23:59:37 -0000      1.6
+++ usr.bin/ctags/print.c       19 Feb 2012 11:25:53 -0000
@@ -42 +42 @@
- * getline --
+ * get_line --
@@ -47 +47 @@ void
-getline(void)
+get_line(void)
Index: usr.bin/ctags/yacc.c
===================================================================
RCS file: /cvs/src/usr.bin/ctags/yacc.c,v
retrieving revision 1.8
diff -u -p -U0 -r1.8 yacc.c
--- usr.bin/ctags/yacc.c        27 Oct 2009 23:59:37 -0000      1.8
+++ usr.bin/ctags/yacc.c        19 Feb 2012 11:25:53 -0000
@@ -96 +96 @@ y_entries(void)
-                       getline();              /* may change before ':' */
+                       get_line();             /* may change before ':' */
Index: usr.bin/cvs/diff3.c
===================================================================
RCS file: /cvs/src/usr.bin/cvs/diff3.c,v
retrieving revision 1.54
diff -u -p -U0 -r1.54 diff3.c
--- usr.bin/cvs/diff3.c 29 Oct 2010 17:49:37 -0000      1.54
+++ usr.bin/cvs/diff3.c 19 Feb 2012 11:25:53 -0000
@@ -136 +136 @@ static char *getchange(FILE *);
-static char *getline(FILE *, size_t *);
+static char *get_line(FILE *, size_t *);
@@ -506 +506 @@ getchange(FILE *b)
-       while ((line = getline(b, NULL))) {
+       while ((line = get_line(b, NULL))) {
@@ -515 +515 @@ static char *
-getline(FILE *b, size_t *n)
+get_line(FILE *b, size_t *n)
@@ -717 +717 @@ skip(int i, int from, char *pr)
-               if ((line = getline(fp[i], &j)) == NULL)
+               if ((line = get_line(fp[i], &j)) == NULL)
Index: usr.bin/diff3/diff3prog.c
===================================================================
RCS file: /cvs/src/usr.bin/diff3/diff3prog.c,v
retrieving revision 1.11
diff -u -p -U0 -r1.11 diff3prog.c
--- usr.bin/diff3/diff3prog.c   27 Oct 2009 23:59:37 -0000      1.11
+++ usr.bin/diff3/diff3prog.c   19 Feb 2012 11:25:53 -0000
@@ -127 +127 @@ char *getchange(FILE *);
-char *getline(FILE *, size_t *);
+char *get_line(FILE *, size_t *);
@@ -256 +256 @@ getchange(FILE *b)
-       while ((line = getline(b, NULL))) {
+       while ((line = get_line(b, NULL))) {
@@ -264 +264 @@ char *
-getline(FILE *b, size_t *n)
+get_line(FILE *b, size_t *n)
@@ -459 +459 @@ skip(int i, int from, char *pr)
-               if ((line = getline(fp[i], &j)) == NULL)
+               if ((line = get_line(fp[i], &j)) == NULL)
Index: usr.bin/fsplit/fsplit.c
===================================================================
RCS file: /cvs/src/usr.bin/fsplit/fsplit.c,v
retrieving revision 1.18
diff -u -p -U0 -r1.18 fsplit.c
--- usr.bin/fsplit/fsplit.c     27 Oct 2009 23:59:38 -0000      1.18
+++ usr.bin/fsplit/fsplit.c     19 Feb 2012 11:25:53 -0000
@@ -48 +48 @@ int lname(char *, size_t);
-int getline(void);
+int get_line(void);
@@ -164 +164 @@ main(int argc, char *argv[])
-               while (getline() > 0) {
+               while (get_line() > 0) {
@@ -255 +255 @@ int
-getline(void)
+get_line(void)
Index: usr.bin/gencat/gencat.c
===================================================================
RCS file: /cvs/src/usr.bin/gencat/gencat.c,v
retrieving revision 1.14
diff -u -p -U0 -r1.14 gencat.c
--- usr.bin/gencat/gencat.c     1 Jan 2011 11:25:54 -0000       1.14
+++ usr.bin/gencat/gencat.c     19 Feb 2012 11:25:54 -0000
@@ -109 +109 @@ static  void    nomem(void);
-static char   *getline(int);
+static char   *get_line(int);
@@ -225 +225 @@ static char *
-getline(int fd)
+get_line(int fd)
@@ -328 +328 @@ getmsg(int fd, char *cptr, char quote)
-                               cptr = getline(fd);
+                               cptr = get_line(fd);
@@ -414 +414 @@ MCParse(int fd)
-       while ((cptr = getline(fd))) {
+       while ((cptr = get_line(fd))) {
Index: usr.bin/rcs/diff3.c
===================================================================
RCS file: /cvs/src/usr.bin/rcs/diff3.c,v
retrieving revision 1.32
diff -u -p -U0 -r1.32 diff3.c
--- usr.bin/rcs/diff3.c 20 Apr 2011 19:34:16 -0000      1.32
+++ usr.bin/rcs/diff3.c 19 Feb 2012 11:25:55 -0000
@@ -134 +134 @@ static char *getchange(FILE *);
-static char *getline(FILE *, size_t *);
+static char *get_line(FILE *, size_t *);
@@ -615 +615 @@ getchange(FILE *b)
-       while ((line = getline(b, NULL))) {
+       while ((line = get_line(b, NULL))) {
@@ -624 +624 @@ static char *
-getline(FILE *b, size_t *n)
+get_line(FILE *b, size_t *n)
@@ -826 +826 @@ skip(int i, int from, char *pr)
-               if ((line = getline(fp[i], &j)) == NULL)
+               if ((line = get_line(fp[i], &j)) == NULL)
Index: usr.bin/rs/rs.c
===================================================================
RCS file: /cvs/src/usr.bin/rs/rs.c,v
retrieving revision 1.20
diff -u -p -U0 -r1.20 rs.c
--- usr.bin/rs/rs.c     27 Oct 2009 23:59:42 -0000      1.20
+++ usr.bin/rs/rs.c     19 Feb 2012 11:25:55 -0000
@@ -81 +81 @@ void        getfile(void);
-int      getline(void);
+int      get_line(void);
@@ -117 +117 @@ getfile(void)
-               getline();
+               get_line();
@@ -121 +121 @@ getfile(void)
-       getline();
+       get_line();
@@ -167 +167 @@ getfile(void)
-       } while (getline() != EOF);
+       } while (get_line() != EOF);
@@ -306 +306 @@ int
-getline(void)  /* get line; maintain curline, curlen; manage storage */
+get_line(void) /* get line; maintain curline, curlen; manage storage */
Index: usr.bin/unifdef/unifdef.c
===================================================================
RCS file: /cvs/src/usr.bin/unifdef/unifdef.c,v
retrieving revision 1.14
diff -u -p -U0 -r1.14 unifdef.c
--- usr.bin/unifdef/unifdef.c   27 Oct 2009 23:59:46 -0000      1.14
+++ usr.bin/unifdef/unifdef.c   19 Feb 2012 11:25:56 -0000
@@ -186 +186 @@ static void             flushline(bool);
-static Linetype         getline(void);
+static Linetype         get_line(void);
@@ -666 +666 @@ process(void)
-               lineval = getline();
+               lineval = get_line();
@@ -684 +684 @@ static Linetype
-getline(void)
+get_line(void)
Index: usr.bin/uudecode/uudecode.c
===================================================================
RCS file: /cvs/src/usr.bin/uudecode/uudecode.c,v
retrieving revision 1.17
diff -u -p -U0 -r1.17 uudecode.c
--- usr.bin/uudecode/uudecode.c 27 Oct 2009 23:59:46 -0000      1.17
+++ usr.bin/uudecode/uudecode.c 19 Feb 2012 11:25:56 -0000
@@ -307 +307 @@ static int
-getline(char *buf, size_t size)
+get_line(char *buf, size_t size)
@@ -344 +344 @@ uu_decode(void)
-               switch (getline(buf, sizeof(buf))) {
+               switch (get_line(buf, sizeof(buf))) {
@@ -404 +404 @@ uu_decode(void)
-       switch (getline(buf, sizeof(buf))) {
+       switch (get_line(buf, sizeof(buf))) {
@@ -422 +422 @@ base64_decode(void)
-               switch (getline(inbuf, sizeof(inbuf))) {
+               switch (get_line(inbuf, sizeof(inbuf))) {
Index: usr.sbin/ftp-proxy/ftp-proxy.c
===================================================================
RCS file: /cvs/src/usr.sbin/ftp-proxy/ftp-proxy.c,v
retrieving revision 1.23
diff -u -p -U0 -r1.23 ftp-proxy.c
--- usr.sbin/ftp-proxy/ftp-proxy.c      21 Jun 2011 17:31:07 -0000      1.23
+++ usr.sbin/ftp-proxy/ftp-proxy.c      19 Feb 2012 11:25:59 -0000
@@ -96 +96 @@ void      exit_daemon(void);
-int    getline(char *, size_t *);
+int    get_line(char *, size_t *);
@@ -242 +242 @@ client_read(struct bufferevent *bufev, v
-               while ((n = getline(s->cbuf, &s->cbuf_valid)) > 0) {
+               while ((n = get_line(s->cbuf, &s->cbuf_valid)) > 0) {
@@ -336 +336 @@ int
-getline(char *buf, size_t *valid)
+get_line(char *buf, size_t *valid)
@@ -1058 +1058 @@ server_read(struct bufferevent *bufev, v
-               while ((n = getline(s->sbuf, &s->sbuf_valid)) > 0) {
+               while ((n = get_line(s->sbuf, &s->sbuf_valid)) > 0) {
Index: usr.sbin/httpd/src/support/htdigest.c
===================================================================
RCS file: /cvs/src/usr.sbin/httpd/src/support/htdigest.c,v
retrieving revision 1.12
diff -u -p -U0 -r1.12 htdigest.c
--- usr.sbin/httpd/src/support/htdigest.c       11 Aug 2008 17:15:56 -0000      
1.12
+++ usr.sbin/httpd/src/support/htdigest.c       19 Feb 2012 11:26:00 -0000
@@ -105 +105 @@ static int
-getline(char *s, int n, FILE *f)
+get_line(char *s, int n, FILE *f)
@@ -240 +240 @@ int main(int argc, char *argv[])
-    while (!(getline(line, MAX_STRING_LEN, f))) {
+    while (!(get_line(line, MAX_STRING_LEN, f))) {
Index: usr.sbin/httpd/src/support/htpasswd.c
===================================================================
RCS file: /cvs/src/usr.sbin/httpd/src/support/htpasswd.c,v
retrieving revision 1.18
diff -u -p -U0 -r1.18 htpasswd.c
--- usr.sbin/httpd/src/support/htpasswd.c       11 Aug 2008 17:15:56 -0000      
1.18
+++ usr.sbin/httpd/src/support/htpasswd.c       19 Feb 2012 11:26:00 -0000
@@ -133 +133 @@ static int
-getline(char *s, int n, FILE *f)
+get_line(char *s, int n, FILE *f)
@@ -516 +516 @@ main(int argc, char *argv[])
-               while (! (getline(line, sizeof(line), fpw))) {
+               while (! (get_line(line, sizeof(line), fpw))) {
Index: usr.sbin/httpd/src/support/logresolve.c
===================================================================
RCS file: /cvs/src/usr.sbin/httpd/src/support/logresolve.c,v
retrieving revision 1.15
diff -u -p -U0 -r1.15 logresolve.c
--- usr.sbin/httpd/src/support/logresolve.c     21 Jun 2009 00:38:22 -0000      
1.15
+++ usr.sbin/httpd/src/support/logresolve.c     19 Feb 2012 11:26:01 -0000
@@ -52 +52 @@ static void cgethost(struct sockaddr *sa
-static int getline(char *s, int n);
+static int get_line(char *s, int n);
@@ -261 +261 @@ static int
-getline(char *s, int n)
+get_line(char *s, int n)
@@ -311 +311 @@ int main
-       while (getline(line, MAXLINE)) {
+       while (get_line(line, MAXLINE)) {
Index: usr.sbin/lpr/common_source/common.c
===================================================================
RCS file: /cvs/src/usr.sbin/lpr/common_source/common.c,v
retrieving revision 1.33
diff -u -p -U0 -r1.33 common.c
--- usr.sbin/lpr/common_source/common.c 27 Oct 2009 23:59:51 -0000      1.33
+++ usr.sbin/lpr/common_source/common.c 19 Feb 2012 11:26:01 -0000
@@ -202 +202 @@ int
-getline(FILE *cfp)
+get_line(FILE *cfp)
Index: usr.sbin/lpr/common_source/displayq.c
===================================================================
RCS file: /cvs/src/usr.sbin/lpr/common_source/displayq.c,v
retrieving revision 1.31
diff -u -p -U0 -r1.31 displayq.c
--- usr.sbin/lpr/common_source/displayq.c       27 Oct 2009 23:59:51 -0000      
1.31
+++ usr.sbin/lpr/common_source/displayq.c       19 Feb 2012 11:26:01 -0000
@@ -355 +355 @@ inform(char *cf, int rank)
-       while (getline(cfp)) {
+       while (get_line(cfp)) {
Index: usr.sbin/lpr/common_source/lp.h
===================================================================
RCS file: /cvs/src/usr.sbin/lpr/common_source/lp.h,v
retrieving revision 1.14
diff -u -p -U0 -r1.14 lp.h
--- usr.sbin/lpr/common_source/lp.h     2 Jun 2003 23:36:53 -0000       1.14
+++ usr.sbin/lpr/common_source/lp.h     19 Feb 2012 11:26:01 -0000
@@ -133 +133 @@ __dead void fatal(const char *, ...)
-int     getline(FILE *);
+int     get_line(FILE *);
Index: usr.sbin/lpr/common_source/rmjob.c
===================================================================
RCS file: /cvs/src/usr.sbin/lpr/common_source/rmjob.c,v
retrieving revision 1.18
diff -u -p -U0 -r1.18 rmjob.c
--- usr.sbin/lpr/common_source/rmjob.c  27 Oct 2009 23:59:51 -0000      1.18
+++ usr.sbin/lpr/common_source/rmjob.c  19 Feb 2012 11:26:01 -0000
@@ -174 +174 @@ lockchk(char *s)
-       if (!getline(fp)) {
+       if (!get_line(fp)) {
@@ -214 +214 @@ process(char *file)
-       while (getline(cfp)) {
+       while (get_line(cfp)) {
@@ -269 +269 @@ chk(char *file)
-       while (getline(cfp)) {
+       while (get_line(cfp)) {
Index: usr.sbin/lpr/lpc/cmds.c
===================================================================
RCS file: /cvs/src/usr.sbin/lpr/lpc/cmds.c,v
retrieving revision 1.21
diff -u -p -U0 -r1.21 cmds.c
--- usr.sbin/lpr/lpc/cmds.c     29 Oct 2009 20:11:09 -0000      1.21
+++ usr.sbin/lpr/lpc/cmds.c     19 Feb 2012 11:26:02 -0000
@@ -168 +168 @@ abortpr(int dis)
-       if (!getline(fp) || flock(fileno(fp), LOCK_SH|LOCK_NB) == 0) {
+       if (!get_line(fp) || flock(fileno(fp), LOCK_SH|LOCK_NB) == 0) {
@@ -1101 +1101 @@ doarg(char *job)
-               while (getline(fp) > 0)
+               while (get_line(fp) > 0)
Index: usr.sbin/netgroup_mkdb/netgroup_mkdb.c
===================================================================
RCS file: /cvs/src/usr.sbin/netgroup_mkdb/netgroup_mkdb.c,v
retrieving revision 1.15
diff -u -p -U0 -r1.15 netgroup_mkdb.c
--- usr.sbin/netgroup_mkdb/netgroup_mkdb.c      27 Oct 2009 23:59:53 -0000      
1.15
+++ usr.sbin/netgroup_mkdb/netgroup_mkdb.c      19 Feb 2012 11:26:03 -0000
@@ -215 +215 @@ ng_load(const char *fname)
-       while ((buf = getline(fp, &size)) != NULL) {
+       while ((buf = get_line(fp, &size)) != NULL) {
Index: usr.sbin/netgroup_mkdb/util.c
===================================================================
RCS file: /cvs/src/usr.sbin/netgroup_mkdb/util.c,v
retrieving revision 1.5
diff -u -p -U0 -r1.5 util.c
--- usr.sbin/netgroup_mkdb/util.c       27 Oct 2009 23:59:53 -0000      1.5
+++ usr.sbin/netgroup_mkdb/util.c       19 Feb 2012 11:26:03 -0000
@@ -64 +64 @@ erealloc(void *p, size_t s)
-/* getline():
+/* get_line():
@@ -69 +69 @@ char *
-getline(FILE *fp, size_t *size)
+get_line(FILE *fp, size_t *size)
Index: usr.sbin/netgroup_mkdb/util.h
===================================================================
RCS file: /cvs/src/usr.sbin/netgroup_mkdb/util.h,v
retrieving revision 1.2
diff -u -p -U0 -r1.2 util.h
--- usr.sbin/netgroup_mkdb/util.h       16 Feb 2002 21:28:06 -0000      1.2
+++ usr.sbin/netgroup_mkdb/util.h       19 Feb 2012 11:26:03 -0000
@@ -39 +39 @@ void *erealloc(void *, size_t);
-char *getline(FILE *, size_t *);
+char *get_line(FILE *, size_t *);

Reply via email to
Index: usr.bin/csplit/csplit.c
===================================================================
RCS file: /cvs/src/usr.bin/csplit/csplit.c,v
retrieving revision 1.3
diff -u -p -U0 -r1.3 csplit.c
--- usr.bin/csplit/csplit.c     17 Jul 2006 22:28:11 -0000      1.3
+++ usr.bin/csplit/csplit.c     19 Feb 2012 11:25:53 -0000
@@ -66 +66 @@ void       do_rexp(const char *);
-char   *getline(void);
+char   *get_line(void);
@@ -198 +198 @@ main(int argc, char *argv[])
-               while ((p = getline()) != NULL && fputs(p, ofp) == 0)
+               while ((p = get_line()) != NULL && fputs(p, ofp) == 0)
@@ -273 +273 @@ char *
-getline(void)
+get_line(void)
@@ -294 +294 @@ again: if (fgets(lbuf, sizeof(lbuf), src
/* Conceptually rewind the input (as obtained by getline()) back `n' lines. */
@@ -346 +346 @@ toomuch(FILE *ofp, long n)
* getline() will read from here. Next call will truncate to
@@ -394 +394 @@ do_rexp(const char *expr)
-       while ((p = getline()) != NULL) {
+       while ((p = get_line()) != NULL) {
@@ -420 +420 @@ do_rexp(const char *expr)
-               while (--ofs > 0 && (p = getline()) != NULL)
+               while (--ofs > 0 && (p = get_line()) != NULL)
@@ -454 +454 @@ do_lineno(const char *expr)
-                       if ((p = getline()) == NULL)
+                       if ((p = get_line()) == NULL)
@@ -294 +294 @@ again: if (fgets(lbuf, sizeof(lbuf), src
-/* Conceptually rewind the input (as obtained by getline()) back `n' lines. */
+/* Conceptually rewind the input (as obtained by get_line()) back `n' lines. */
@@ -346 +346 @@ toomuch(FILE *ofp, long n)
-        * getline() will read from here. Next call will truncate to
+        * get_line() will read from here. Next call will truncate to
Index: usr.sbin/lpr/lpd/printjob.c
===================================================================
RCS file: /cvs/src/usr.sbin/lpr/lpd/printjob.c,v
retrieving revision 1.46
diff -u -p -U0 -r1.46 printjob.c
--- usr.sbin/lpr/lpd/printjob.c 22 Mar 2010 16:50:38 -0000      1.46
+++ usr.sbin/lpr/lpd/printjob.c 19 Feb 2012 11:26:02 -0000
@@ -390 +390 @@ printit(char *file)
*      getline reads a line and expands tabs to blanks
@@ -395 +395 @@ printit(char *file)
-       while (getline(cfp))
+       while (get_line(cfp))
@@ -496 +496 @@ pass2:
-       while (getline(cfp))
+       while (get_line(cfp))
@@ -811 +811 @@ sendit(char *file)
-       while (getline(cfp)) {
+       while (get_line(cfp)) {
@@ -828 +828 @@ sendit(char *file)
-                       while ((i = getline(cfp)) != 0)
+                       while ((i = get_line(cfp)) != 0)
@@ -855 +855 @@ sendit(char *file)
-       while (getline(cfp))
+       while (get_line(cfp))
@@ -390 +390 @@ printit(char *file)
-        *      getline reads a line and expands tabs to blanks
+        *      get_line reads a line and expands tabs to blanks